@@ -3,18 +3,19 @@
 
 #define FAST_BUILD
 #define ZLIB_FOUND
+/* #undef CUPDLP_CPU */
 #define CMAKE_BUILD_TYPE "Release"
 #define CMAKE_INSTALL_PREFIX "/clangarm64"
 /* #undef HIGHSINT64 */
+/* #undef HIGHS_NO_DEFAULT_THREADS */
 /* #undef HIGHS_HAVE_MM_PAUSE */
 #define HIGHS_HAVE_BUILTIN_CLZ
 /* #undef HIGHS_HAVE_BITSCAN_REVERSE */
 
 #define HIGHS_GITHASH "n/a"
-#define HIGHS_COMPILATION_DATE "2023-10-04"
 #define HIGHS_VERSION_MAJOR 1
-#define HIGHS_VERSION_MINOR 6
+#define HIGHS_VERSION_MINOR 8
 #define HIGHS_VERSION_PATCH 0
-#define HIGHS_DIR "C:/M/B/src/HiGHS-1.6.0"
+#define HIGHS_DIR "C:/M/B/src/HiGHS-1.8.0"
 
 #endif /* HCONFIG_H_ */
